@@ -5,16 +5,15 @@ class Transactions(object):
     savepoint = None
     db = None
 
-    def __init__(self, savepoint):
-        app = WeDeliverCore.getApp()
+    def __init__(self):
+        app = WeDeliverCore.get_app()
 
         self.db = app.extensions['sqlalchemy'].db
-        self.savepoint = savepoint
+        self.savepoint = self.db.session.begin_nested()
 
     @staticmethod
-    def atomic(session):
-        savepoint = session.begin_nested()
-        return Transactions(savepoint)
+    def atomic():
+        return Transactions()
 
     def __enter__(self):
         return self
