@@ -3,9 +3,7 @@ from datetime import datetime
 
 from .kafka_producer import Producer
 from .. import WeDeliverCore
-
-INTERNAL_NOTIFICATION_MESSAGE = "internal_notification_message"
-
+from wedeliver_core.helpers.topics import Topics
 
 def send_critical_error(message, channel=None):
     channel = channel or "critical-errors"
@@ -32,8 +30,6 @@ def send_notification_message(
     message = "Node: {0}\nEnv:{3}\nDate: {1}\n{2}".format(
         platform.node(), datetime.now(), message, str(app.config.get("FLASK_ENV"))
     )
-    print(channel)
-    print(message)
     data = {
         "notification_method": "slack",
         "payload": {
@@ -47,4 +43,4 @@ def send_notification_message(
         },
     }
     app.logger.debug(data)
-    Producer().send_topic(topic=INTERNAL_NOTIFICATION_MESSAGE, datajson=data)
+    Producer().send_topic(topic=Topics.INTERNAL_NOTIFICATION_MESSAGE, datajson=data)
